@@ -310,6 +310,9 @@ impl Database {
                                 .provides
                                 .contains(&ExtensionProvides::ContextServers),
                         ),
+                        provides_agent_servers: ActiveValue::Set(
+                            version.provides.contains(&ExtensionProvides::AgentServers),
+                        ),
                         provides_slash_commands: ActiveValue::Set(
                             version.provides.contains(&ExtensionProvides::SlashCommands),
                         ),
@@ -422,6 +425,10 @@ fn apply_provides_filter(
         condition = condition.add(extension_version::Column::ProvidesContextServers.eq(true));
     }
 
+    if provides_filter.contains(&ExtensionProvides::AgentServers) {
+        condition = condition.add(extension_version::Column::ProvidesAgentServers.eq(true));
+    }
+
     if provides_filter.contains(&ExtensionProvides::SlashCommands) {
         condition = condition.add(extension_version::Column::ProvidesSlashCommands.eq(true));
     }
