@@ -174,7 +174,6 @@ impl TestServer {
             cx.set_global(settings);
             theme::init(theme::LoadThemes::JustBase, cx);
             release_channel::init(SemanticVersion::default(), cx);
-            client::init_settings(cx);
         });
 
         let clock = Arc::new(FakeSystemClock::new());
@@ -345,7 +344,6 @@ impl TestServer {
             theme::init(theme::LoadThemes::JustBase, cx);
             Project::init(&client, cx);
             client::init(&client, cx);
-            language::init(cx);
             editor::init(cx);
             workspace::init(app_state.clone(), cx);
             call::init(client.clone(), user_store.clone(), cx);
@@ -359,7 +357,6 @@ impl TestServer {
             );
             language_model::LanguageModelRegistry::test(cx);
             assistant_text_thread::init(client.clone(), cx);
-            agent_settings::init(cx);
         });
 
         client
