@@ -1,6 +1,7 @@
 mod bitbucket;
 mod chromium;
-mod codeberg;
+mod forgejo;
+mod gitea;
 mod gitee;
 mod github;
 mod gitlab;
@@ -8,7 +9,8 @@ mod sourcehut;
 
 pub use bitbucket::*;
 pub use chromium::*;
-pub use codeberg::*;
+pub use forgejo::*;
+pub use gitea::*;
 pub use gitee::*;
 pub use github::*;
 pub use gitlab::*;
