@@ -1,28 +1,6 @@
 use std::ops::Deref;
 
-use windows::Win32::{Foundation::HANDLE, UI::WindowsAndMessaging::HCURSOR};
-
-#[derive(Debug, Clone, Copy)]
-pub(crate) struct SafeHandle {
-    raw: HANDLE,
-}
-
-unsafe impl Send for SafeHandle {}
-unsafe impl Sync for SafeHandle {}
-
-impl From<HANDLE> for SafeHandle {
-    fn from(value: HANDLE) -> Self {
-        SafeHandle { raw: value }
-    }
-}
-
-impl Deref for SafeHandle {
-    type Target = HANDLE;
-
-    fn deref(&self) -> &Self::Target {
-        &self.raw
-    }
-}
+use windows::Win32::{Foundation::HWND, UI::WindowsAndMessaging::HCURSOR};
 
 #[derive(Debug, Clone, Copy)]
 pub(crate) struct SafeCursor {
@@ -45,3 +23,31 @@ impl Deref for SafeCursor {
         &self.raw
     }
 }
+
+#[derive(Debug, Clone, Copy)]
+pub(crate) struct SafeHwnd {
+    raw: HWND,
+}
+
+impl SafeHwnd {
+    pub(crate) fn as_raw(&self) -> HWND {
+        self.raw
+    }
+}
+
+unsafe impl Send for SafeHwnd {}
+unsafe impl Sync for SafeHwnd {}
+
+impl From<HWND> for SafeHwnd {
+    fn from(value: HWND) -> Self {
+        SafeHwnd { raw: value }
+    }
+}
+
+impl Deref for SafeHwnd {
+    type Target = HWND;
+
+    fn deref(&self) -> &Self::Target {
+        &self.raw
+    }
+}
