@@ -35,6 +35,7 @@ pub enum IconName {
     ArrowUp,
     ArrowUpRight,
     Attach,
+    AtSign,
     AudioOff,
     AudioOn,
     Backspace,
@@ -53,6 +54,7 @@ pub enum IconName {
     Check,
     CheckDouble,
     ChevronDown,
+    ChevronDownUp,
     ChevronLeft,
     ChevronRight,
     ChevronUp,
@@ -145,6 +147,7 @@ pub enum IconName {
     Keyboard,
     Library,
     LineHeight,
+    Link,
     ListCollapse,
     ListFilter,
     ListTodo,
@@ -256,8 +259,8 @@ pub enum IconName {
     ZedAssistant,
     ZedBurnMode,
     ZedBurnModeOn,
-    ZedMcpCustom,
-    ZedMcpExtension,
+    ZedSrcCustom,
+    ZedSrcExtension,
     ZedPredict,
     ZedPredictDisabled,
     ZedPredictDown,
