@@ -19,11 +19,12 @@ use std::pin::Pin;
 use std::str::FromStr;
 use std::sync::{Arc, LazyLock};
 use strum::IntoEnumIterator;
-use ui::{Icon, IconName, List, Tooltip, prelude::*};
+use ui::{List, prelude::*};
 use ui_input::InputField;
-use util::{ResultExt, truncate_and_trailoff};
+use util::ResultExt;
 use zed_env_vars::{EnvVar, env_var};
 
+use crate::ui::ConfiguredApiCard;
 use crate::{api_key::ApiKeyState, ui::InstructionListItem};
 
 const PROVIDER_ID: LanguageModelProviderId = LanguageModelProviderId::new("mistral");
@@ -719,6 +720,7 @@ impl MistralEventMapper {
                         is_input_complete: true,
                         input,
                         raw_input: tool_call.arguments,
+                        thought_signature: None,
                     },
                 ))),
                 Err(error) => {
@@ -753,9 +755,9 @@ struct ConfigurationView {
 impl ConfigurationView {
     fn new(state: Entity<State>, window: &mut Window, cx: &mut Context<Self>) -> Self {
         let api_key_editor =
-            cx.new(|cx| InputField::new(window, cx, "0aBCDEFGhIjKLmNOpqrSTUVwxyzabCDE1f2"));
+            cx.new(|cx| InputField::new(window, cx, "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"));
         let codestral_api_key_editor =
-            cx.new(|cx| InputField::new(window, cx, "0aBCDEFGhIjKLmNOpqrSTUVwxyzabCDE1f2"));
+            cx.new(|cx| InputField::new(window, cx, "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"));
 
         cx.observe(&state, |_, _, cx| {
             cx.notify();
@@ -883,6 +885,12 @@ impl ConfigurationView {
         let key_state = &self.state.read(cx).codestral_api_key_state;
         let should_show_editor = !key_state.has_key();
         let env_var_set = key_state.is_from_env_var();
+        let configured_card_label = if env_var_set {
+            format!("API key set in {CODESTRAL_API_KEY_ENV_VAR_NAME} environment variable")
+        } else {
+            "Codestral API key configured".to_string()
+        };
+
         if should_show_editor {
             v_flex()
                 .id("codestral")
@@ -910,42 +918,19 @@ impl ConfigurationView {
                     .size(LabelSize::Small).color(Color::Muted),
                 ).into_any()
         } else {
-            h_flex()
-                .id("codestral")
-                .mt_2()
-                .p_1()
-                .justify_between()
-                .rounded_md()
-                .border_1()
-                .border_color(cx.theme().colors().border)
-                .bg(cx.theme().colors().background)
-                .child(
-                    h_flex()
-                        .gap_1()
-                        .child(Icon::new(IconName::Check).color(Color::Success))
-                        .child(Label::new(if env_var_set {
-                            format!("API key set in {CODESTRAL_API_KEY_ENV_VAR_NAME} environment variable")
-                        } else {
-                            "Codestral API key configured".to_string()
-                        })),
+            ConfiguredApiCard::new(configured_card_label)
+                .disabled(env_var_set)
+                .on_click(cx.listener(|this, _, window, cx| this.reset_api_key(window, cx)))
+                .when(env_var_set, |this| {
+                    this.tooltip_label(format!(
+                        "To reset your API key, \
+                            unset the {CODESTRAL_API_KEY_ENV_VAR_NAME} environment variable."
+                    ))
+                })
+                .on_click(
+                    cx.listener(|this, _, window, cx| this.reset_codestral_api_key(window, cx)),
                 )
-                .child(
-                    Button::new("reset-key", "Reset Key")
-                        .label_size(LabelSize::Small)
-                        .icon(Some(IconName::Trash))
-                        .icon_size(IconSize::Small)
-                        .icon_position(IconPosition::Start)
-                        .disabled(env_var_set)
-                        .when(env_var_set, |this| {
-                            this.tooltip(Tooltip::text(format!(
-                                "To reset your API key, \
-                                unset the {CODESTRAL_API_KEY_ENV_VAR_NAME} environment variable."
-                            )))
-                        })
-                        .on_click(
-                            cx.listener(|this, _, window, cx| this.reset_codestral_api_key(window, cx)),
-                        ),
-                ).into_any()
+                .into_any_element()
         }
     }
 }
@@ -953,6 +938,16 @@ impl ConfigurationView {
 impl Render for ConfigurationView {
     fn render(&mut self, _window: &mut Window, cx: &mut Context<Self>) -> impl IntoElement {
         let env_var_set = self.state.read(cx).api_key_state.is_from_env_var();
+        let configured_card_label = if env_var_set {
+            format!("API key set in {API_KEY_ENV_VAR_NAME} environment variable")
+        } else {
+            let api_url = MistralLanguageModelProvider::api_url(cx);
+            if api_url == MISTRAL_API_URL {
+                "API key configured".to_string()
+            } else {
+                format!("API key configured for {}", api_url)
+            }
+        };
 
         if self.load_credentials_task.is_some() {
             div().child(Label::new("Loading credentials...")).into_any()
@@ -987,52 +982,17 @@ impl Render for ConfigurationView {
         } else {
             v_flex()
                 .size_full()
+                .gap_1()
                 .child(
-                    h_flex()
-                        .mt_1()
-                        .p_1()
-                        .justify_between()
-                        .rounded_md()
-                        .border_1()
-                        .border_color(cx.theme().colors().border)
-                        .bg(cx.theme().colors().background)
-                        .child(
-                            h_flex()
-                                .gap_1()
-                                .child(Icon::new(IconName::Check).color(Color::Success))
-                                .child(Label::new(if env_var_set {
-                                    format!(
-                                        "API key set in {API_KEY_ENV_VAR_NAME} environment variable"
-                                    )
-                                } else {
-                                    let api_url = MistralLanguageModelProvider::api_url(cx);
-                                    if api_url == MISTRAL_API_URL {
-                                        "API key configured".to_string()
-                                    } else {
-                                        format!(
-                                            "API key configured for {}",
-                                            truncate_and_trailoff(&api_url, 32)
-                                        )
-                                    }
-                                })),
-                        )
-                        .child(
-                            Button::new("reset-key", "Reset Key")
-                                .label_size(LabelSize::Small)
-                                .icon(Some(IconName::Trash))
-                                .icon_size(IconSize::Small)
-                                .icon_position(IconPosition::Start)
-                                .disabled(env_var_set)
-                                .when(env_var_set, |this| {
-                                    this.tooltip(Tooltip::text(format!(
-                                        "To reset your API key, \
-                                        unset the {API_KEY_ENV_VAR_NAME} environment variable."
-                                    )))
-                                })
-                                .on_click(cx.listener(|this, _, window, cx| {
-                                    this.reset_api_key(window, cx)
-                                })),
-                        ),
+                    ConfiguredApiCard::new(configured_card_label)
+                        .disabled(env_var_set)
+                        .on_click(cx.listener(|this, _, window, cx| this.reset_api_key(window, cx)))
+                        .when(env_var_set, |this| {
+                            this.tooltip_label(format!(
+                                "To reset your API key, \
+                                unset the {API_KEY_ENV_VAR_NAME} environment variable."
+                            ))
+                        }),
                 )
                 .child(self.render_codestral_api_key_editor(cx))
                 .into_any()
@@ -1065,11 +1025,13 @@ mod tests {
                     role: Role::System,
                     content: vec![MessageContent::Text("System prompt".into())],
                     cache: false,
+                    reasoning_details: None,
                 },
                 LanguageModelRequestMessage {
                     role: Role::User,
                     content: vec![MessageContent::Text("Hello".into())],
                     cache: false,
+                    reasoning_details: None,
                 },
             ],
             temperature: Some(0.5),
@@ -1104,6 +1066,7 @@ mod tests {
                     }),
                 ],
                 cache: false,
+                reasoning_details: None,
             }],
             tools: vec![],
             tool_choice: None,
