@@ -2199,11 +2199,9 @@ impl RemoteServerProjects {
 fn spawn_ssh_config_watch(fs: Arc<dyn Fs>, cx: &Context<RemoteServerProjects>) -> Task<()> {
     let mut user_ssh_config_watcher =
         watch_config_file(cx.background_executor(), fs.clone(), user_ssh_config_file());
-    let mut global_ssh_config_watcher = watch_config_file(
-        cx.background_executor(),
-        fs,
-        global_ssh_config_file().to_owned(),
-    );
+    let mut global_ssh_config_watcher = global_ssh_config_file()
+        .map(|it| watch_config_file(cx.background_executor(), fs, it.to_owned()))
+        .unwrap_or_else(|| futures::channel::mpsc::unbounded().1);
 
     cx.spawn(async move |remote_server_projects, cx| {
         let mut global_hosts = BTreeSet::default();
