@@ -15,6 +15,12 @@ pub struct ProcessIdGetter {
     fallback_pid: u32,
 }
 
+impl ProcessIdGetter {
+    pub fn fallback_pid(&self) -> Pid {
+        Pid::from_u32(self.fallback_pid)
+    }
+}
+
 #[cfg(unix)]
 impl ProcessIdGetter {
     fn new(pty: &Pty) -> ProcessIdGetter {
@@ -31,10 +37,6 @@ impl ProcessIdGetter {
         }
         Some(Pid::from_u32(pid as u32))
     }
-
-    pub fn fallback_pid(&self) -> u32 {
-        self.fallback_pid
-    }
 }
 
 #[cfg(windows)]
@@ -66,10 +68,6 @@ impl ProcessIdGetter {
         }
         Some(Pid::from_u32(pid))
     }
-
-    pub fn fallback_pid(&self) -> u32 {
-        self.fallback_pid
-    }
 }
 
 #[derive(Clone, Debug)]
@@ -122,10 +120,19 @@ impl PtyProcessInfo {
         }
     }
 
+    fn get_child(&self) -> Option<&Process> {
+        let pid = self.pid_getter.fallback_pid();
+        self.system.process(pid)
+    }
+
     pub(crate) fn kill_current_process(&mut self) -> bool {
         self.refresh().is_some_and(|process| process.kill())
     }
 
+    pub(crate) fn kill_child_process(&mut self) -> bool {
+        self.get_child().is_some_and(|process| process.kill())
+    }
+
     fn load(&mut self) -> Option<ProcessInfo> {
         let process = self.refresh()?;
         let cwd = process.cwd().map_or(PathBuf::new(), |p| p.to_owned());
